cobib-tutorial(1) -- an interactive guided tutorial
===================================================

## SYNOPSIS

`cobib tutorial`

## DESCRIPTION

An interactive guided tutorial.
This command starts an interactive *cobib-shell(7)* with a guided tutorial to teach the basics of working with *cobib(1)*.
As such, this command can only be started from the CLI but not from within an already running *cobib-shell(7)* or *cobib-tui(7)*.

The contents of the tutorial are more extensive than the rather brief *cobib-getting-started(7)* page.
A preview of the tutorial's instructions can be found in the [online documentation](https://cobib.gitlab.io/cobib/cobib/commands/tutorial.html).

## EXAMPLES

```bash
$ cobib tutorial
```

## SEE ALSO

*cobib(1)*, *cobib-getting-started(7)*, *cobib-commands(7)*, *cobib-shell(7)*

[//]: # ( vim: set ft=markdown tw=0: )
